@@ -27,6 +27,7 @@ from pulpcore.plugin.viewsets import (
     RemoteViewSet,
     RepositoryViewSet,
     RepositoryVersionViewSet,
+    SingleArtifactContentUploadViewSet,
 )
 from pulp_ansible.app.galaxy.mixins import UploadGalaxyCollectionMixin
 from .models import (
@@ -46,6 +47,7 @@ from .serializers import (
     AnsibleRepositorySyncURLSerializer,
     CollectionSerializer,
     CollectionVersionSerializer,
+    CollectionVersionUploadSerializer,
     CollectionRemoteSerializer,
     CollectionOneShotSerializer,
     CopySerializer,
@@ -162,7 +164,7 @@ class CollectionVersionFilter(ContentFilter):
         fields = ["namespace", "name", "version", "q", "is_highest", "tags"]
 
 
-class CollectionVersionViewSet(ContentViewSet):
+class CollectionVersionViewSet(SingleArtifactContentUploadViewSet, UploadGalaxyCollectionMixin):
     """
     ViewSet for Ansible Collection.
     """
@@ -174,6 +176,33 @@ class CollectionVersionViewSet(ContentViewSet):
     filter_backends = (OrderingFilter, DjangoFilterBackend)
     ordering_fields = ("pulp_created", "name", "version", "namespace")
 
+    @extend_schema(
+        description="Trigger an asynchronous task to create content,"
+        "optionally create new repository version.",
+        request=CollectionVersionUploadSerializer,
+        responses={202: AsyncOperationResponseSerializer},
+    )
+    def create(self, request):
+        """Create a content unit."""
+        serializer = CollectionVersionUploadSerializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+
+        kwargs = {}
+        if serializer.validated_data["namespace"]:
+            kwargs["expected_namespace"] = serializer.validated_data["namespace"]
+
+        if serializer.validated_data["name"]:
+            kwargs["expected_name"] = serializer.validated_data["name"]
+
+        if serializer.validated_data["version"]:
+            kwargs["expected_version"] = serializer.validated_data["version"]
+
+        temp_file_pk = serializer.validated_data["temp_file_pk"]
+        repository = serializer.validated_data.get("repository")
+        async_result = self._dispatch_import_collection_task(temp_file_pk, repository, **kwargs)
+
+        return OperationPostponedResponse(async_result, request)
+
 
 class RoleRemoteViewSet(RemoteViewSet):
     """
